close all
clear all
clc

% -----------------------------------------------------
% PARAMETERS FOR SYSTEM SIMULATION
% -----------------------------------------------------
% This script initializes all the parameters required
% by the simulink model. The script must be called
% before executing the simulation.
% -----------------------------------------------------

% Simulation time (seconds)
T_sim=10; 

% -----------------------------------------------------
% Parameters used by the motor block
% -----------------------------------------------------
Vdd=11.1;
Km=38.46e-3;  % Km=4.3e-3;
Ke=Km;
R=0.67;
L=500e-6;
J=3.4e-5;
tau_elet=L/R;
tau_mech=R*J/(Km*Ke);

% -----------------------------------------------------
% Environmental parameters
% -----------------------------------------------------
global g; % Gravitational acceleration
global mag_field; % Magnetic field vector
global P0; % Pressure at ground level [Pa].
global Ra; % Gas constant of the air [J/(Kg*K)].
global T0; % Temperature at ground level [K].

mag = [cos(deg2rad(61)); -0.1; -sin(deg2rad(61))];
mag_field = mag / norm(mag);
g = 9.81;
P0 = 101325; % Mean value at sea level.
Ra = 286.9;
T0 = 293.15;

% ----------------------------------------------------
% Initial conditions
% ----------------------------------------------------
global x0;
global y0;
global z0;
global phi0;
global theta0;
global psi0;
global dx0;
global dy0;
global dz0;
global dphi0;
global dtheta0;
global dpsi0;

x0=0;
y0=0;
z0=0;
phi0=0;
theta0=0;
psi0=0;
dx0=0;
dy0=0;
dz0=0;
dphi0=0;
dtheta0=0;
dpsi0=0;

% ----------------------------------------------------
% Mechanical parameters
% ----------------------------------------------------
global m; % Mass of the quadrotor
global b; % Thrust factor
global d; % Drag factor

% Diagonal elements of the inertia matrix
global Ix;
global Iy;
global Iz;

global Jr; % Rotor inertia
global l;  % Center of mass-motor distance

m=0.5;
b=7.2e-5;   % 2.9e-5; calculated as b=(m*g/4) / (omega hoovering)^2  
d=1.1e-5; 
Ix=5e-3;
Iy=5e-3;
Iz=9e-3;
Jr=3.4e-5; 
l=0.25;

% Graphics inizialization for draw_mod function
global index_view;
global old_position;

index_view = 0;
old_position = [0 0 0];


% ----------------------------------------------------
% KALMAN FILTER PARAMETERS
% The following parameters are used by the blocks
% related to the Kalman filter. Many of them reproduce
% the parameters used in the system simulation, but
% are distinguished by the suffix _e.
% ----------------------------------------------------
% Physical and environmental parameters
g_e = g;
m_e = m; % + random('normal',0,m/2000);
mf_e = mag_field;
mf_e = mf_e /norm(mf_e);
P0_e = P0;
T0_e = T0;
Ra_e = Ra;
Ix_e = Ix;
Iy_e = Iy;
Iz_e = Iz;

% Sensor parameters
Ma_e = eye(3); % + random('normal',0,0.01,3,3);
ba_e = zeros(3,1); % + random('normal',0,0.01,3,1);
Mg_e = eye(3); % + random('normal',0,0.01,3,3);
bg_e = zeros(3,1); % + random('normal',0,0.01,3,1);
G_e = eye(3); % + random('normal',0,0.01,3,3);
bm_e = zeros(3,1); % + random('normal',0,0.01,3,1);
kb_e = 1;
bb_e = 0;

% Plant and measurement noise covariances
R_e = 0.01*eye(10); % Measurement noise
R_e(10,10) = 10;
Q_e = 0.005*eye(10); % Process noise

% Initial expected value and variance of the state vector.
Ex = zeros(10,1);
Varx = 0.001*eye(10);

% Lowpass filter parameters
[b_filt, a_filt] = butter(4, 50, 's');

% ----------------------------------------------------
% Parameters for the discrete time EKF
% ----------------------------------------------------
% Samplig time.
Ts = 0.05;

% Sensor anti-aliasing filter parameters
[zeros_aa, poles_aa, gain_aa] = butter(1, 0.4/Ts, 's');


disp('initialization done')